@@ -661,6 +661,11 @@ NvU32 NVKMS_API_CALL nvkms_enumerate_gpus(nv_gpu_info_t *gpu_info)
     return 0;
 }
 
+NvBool NVKMS_API_CALL nvkms_allow_write_combining(void)
+{
+    return __rm_ops.system_info.allow_write_combining;
+}
+
 /*************************************************************************
  * NVKMS interface for kernel space NVKMS clients like KAPI
  *************************************************************************/
