@@ -220,6 +220,12 @@ void NVKMS_API_CALL nvkms_close_gpu(NvU32 gpuId);
 
 NvU32 NVKMS_API_CALL nvkms_enumerate_gpus(nv_gpu_info_t *gpu_info);
 
+/*!
+ * Availability of write combining support for video memory.
+ */
+
+NvBool NVKMS_API_CALL nvkms_allow_write_combining(void);
+
 /*!
  * NVKMS interface for kernel space NVKMS clients like KAPI
  */
