@@ -45,12 +45,22 @@
 struct NvKmsKapiDevice;
 struct NvKmsKapiMemory;
 struct NvKmsKapiSurface;
+struct NvKmsKapiChannelEvent;
 
 typedef NvU32 NvKmsKapiConnector;
 typedef NvU32 NvKmsKapiDisplay;
 
 /** @} */
 
+/**
+ * \defgroup FuncPtrs
+ * @{
+ */
+
+typedef void NVKMS_KAPI_CALL NvKmsChannelEventProc(void *dataPtr, NvU32 dataU32);
+
+/** @} */
+
 /**
  * \defgroup Structs
  * @{
@@ -123,6 +133,11 @@ typedef enum NvKmsKapiPlaneTypeRec {
 
 #define NVKMS_KAPI_PLANE_MASK(planeType) (1 << (planeType))
 
+typedef enum NvKmsKapiMappingTypeRec {
+    NVKMS_KAPI_MAPPING_TYPE_USER   = 1,
+    NVKMS_KAPI_MAPPING_TYPE_KERNEL = 2,
+} NvKmsKapiMappingType;
+
 struct NvKmsKapiConnectorInfo {
 
     NvKmsKapiConnector handle;
@@ -256,6 +271,14 @@ struct NvKmsKapiFunctionsTable {
      */
     const char *versionString;
 
+    /*!
+     * System Information.
+     */
+    struct {
+        /* Availability of write combining support for video memory */
+        NvBool bAllowWriteCombining;
+    } systemInfo;
+
     /*!
      * Enumerate the available physical GPUs that can be used with NVKMS.
      *
@@ -491,6 +514,8 @@ struct NvKmsKapiFunctionsTable {
      *
      * \param [in]  memory           Memory allocated using allocateMemory()
      *
+     * \param [in]  type             Userspace or kernelspace mapping
+     *
      * \param [out] ppLinearAddress  The MMIO address where memory object is
      *                               mapped.
      *
@@ -499,7 +524,8 @@ struct NvKmsKapiFunctionsTable {
     NvBool NVKMS_KAPI_CALL (*mapMemory)
     (
         const struct NvKmsKapiDevice *device,
-        const struct NvKmsKapiMemory *memory, void **ppLinearAddress
+        const struct NvKmsKapiMemory *memory, NvKmsKapiMappingType type,
+        void **ppLinearAddress
     );
 
     /*!
@@ -510,12 +536,15 @@ struct NvKmsKapiFunctionsTable {
      *
      * \param [in]  memory           Memory allocated using allocateMemory()
      *
+     * \param [in]  type             Userspace or kernelspace mapping
+     *
      * \param [in]  pLinearAddress   The MMIO address return by mapMemory()
      */
     void NVKMS_KAPI_CALL (*unmapMemory)
     (
         const struct NvKmsKapiDevice *device,
-        const struct NvKmsKapiMemory *memory, const void *pLinearAddress
+        const struct NvKmsKapiMemory *memory, NvKmsKapiMappingType type,
+        const void *pLinearAddress
     );
 
     /*!
@@ -650,6 +679,76 @@ struct NvKmsKapiFunctionsTable {
         const NvKmsKapiPlaneType plane,
         NvBool *pending
     );
+
+    /*!
+     * Allocate an event callback. Disabled by default.
+     *
+     * \param [in]  device          A device allocated using allocateDevice().
+     *
+     * \param [in]  proc            Function pointer to call when triggered.
+     *
+     * \param [in]  data            Argument to pass into function.
+     *
+     * \param [in] nvKmsParamsUser  Userspace pointer to driver-specific
+     *                              parameters describing the event callback
+     *                              being created.
+     *
+     * \param [in] nvKmsParamsSize  Size of the driver-specific parameter struct.
+     *
+     * \return struct NvKmsKapiChannelEvent* on success, NULL on failure.
+     */
+    struct NvKmsKapiChannelEvent* NVKMS_KAPI_CALL (*allocateChannelEvent)
+    (
+        struct NvKmsKapiDevice *device,
+        NvKmsChannelEventProc *proc,
+        void *data,
+        NvU64 nvKmsParamsUser,
+        NvU64 nvKmsParamsSize
+    );
+
+    /*!
+     * Free an event callback.
+     *
+     * \param [in]  device  A device allocated using allocateDevice().
+     *
+     * \param [in]  cb      struct NvKmsKapiChannelEvent* returned from
+     *                      allocateChannelEvent()
+     */
+    void NVKMS_KAPI_CALL (*freeChannelEvent)
+    (
+        struct NvKmsKapiDevice *device,
+        struct NvKmsKapiChannelEvent *cb
+    );
+
+    /*!
+     * Enable an event callback.
+     *
+     * \param [in]  device  A device allocated using allocateDevice().
+     *
+     * \param [in]  cb      struct NvKmsKapiChannelEvent* returned from
+     *                      allocateChannelEvent()
+     *
+     * \return NV_TRUE on success, NV_FALSE on failure.
+     */
+    NvBool NVKMS_KAPI_CALL (*enableChannelEvent)
+    (
+        struct NvKmsKapiDevice *device,
+        struct NvKmsKapiChannelEvent *cb
+    );
+
+    /*!
+     * Disable an event callback.
+     *
+     * \param [in]  device  A device allocated using allocateDevice().
+     *
+     * \param [in]  cb      struct NvKmsKapiChannelEvent* returned from
+     *                      allocateChannelEvent()
+     */
+    void NVKMS_KAPI_CALL (*disableChannelEvent)
+    (
+        struct NvKmsKapiDevice *device,
+        struct NvKmsKapiChannelEvent *cb
+    );
 };
 
 /** @} */
