@@ -26,7 +26,12 @@
 
 typedef struct nvkms_per_open nvkms_per_open_handle_t;
 
-typedef void NVKMS_API_CALL nvkms_procfs_proc_t(char *buffer, size_t size);
+typedef void NVKMS_API_CALL nvkms_procfs_out_string_func_t(void *data,
+                                                           const char *str);
+
+typedef void NVKMS_API_CALL nvkms_procfs_proc_t(void *data,
+                                                char *buffer, size_t size,
+                                                nvkms_procfs_out_string_func_t *outString);
 
 typedef struct {
     const char *name;
