@@ -291,6 +291,16 @@ typedef struct nv_event_s
     struct nv_event_s  *next;
 } nv_event_t;
 
+/*
+ * this is to be able to associate a fd memdesc to a file descriptor
+ */
+typedef struct nv_fd_memdesc_s
+{
+    NvBool              bValid;
+    NvHandle            hParent;
+    NvHandle            hMemory;
+} nv_fd_memdesc_t;
+
 typedef struct nv_kern_mapping_s
 {
     void  *addr;
@@ -303,7 +313,7 @@ typedef struct nv_mmap_context_s
     NvP64 addr;
     NvU64 size;
     NvU32 process_id;
-    NvU64 thread_id;
+    NvU32 thread_id;
     void *file;
     void *os_priv;
     struct nv_mmap_context_s *next;
@@ -353,9 +363,8 @@ typedef struct
 
     nv_kern_mapping_t *kern_mappings;
 
-    void *mmap_mutex;
     nv_mmap_context_t *mmap_contexts;
- 
+
     /* DMA addressable range of the device */
     NvU64 dma_addressable_start;
     NvU64 dma_addressable_limit;
@@ -417,28 +426,27 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 
 #define NV_PRIMARY_VGA(nv)      ((nv)->primary_vga)
 
-#define NV_IS_GVI_DEVICE(nv)    ((nv)->flags & NV_FLAG_GVI)
-#define NV_IS_CTL_DEVICE(nv)    ((nv)->flags & NV_FLAG_CONTROL)
+#define NV_IS_GVI_DEVICE(nv) ((nv)->flags & NV_FLAG_GVI)
 
-/*                                                                                    
- * The ACPI specification defines IDs for various ACPI video                          
- * extension events like display switch events, AC/battery                            
- * events, docking events, etc..                                                      
- * Whenever an ACPI event is received by the corresponding                            
- * event handler installed within the core NVIDIA driver, the                         
- * code can verify the event ID before processing it.                                 
+/*
+ * The ACPI specification defines IDs for various ACPI video
+ * extension events like display switch events, AC/battery
+ * events, docking events, etc..
+ * Whenever an ACPI event is received by the corresponding
+ * event handler installed within the core NVIDIA driver, the
+ * code can verify the event ID before processing it.
  */
-#define ACPI_DISPLAY_DEVICE_CHANGE_EVENT      0x80 
+#define ACPI_DISPLAY_DEVICE_CHANGE_EVENT      0x80
 #define NVIF_NOTIFY_DISPLAY_DETECT           0xCB
-#define NVIF_DISPLAY_DEVICE_CHANGE_EVENT     NVIF_NOTIFY_DISPLAY_DETECT 
-/*                                                                                    
- * NVIDIA ACPI event IDs to be passed into the core NVIDIA                            
- * driver for various events like display switch events,                              
- * AC/battery events, docking events, etc..                                           
- */                                                                                   
-#define NV_SYSTEM_ACPI_DISPLAY_SWITCH_EVENT  0x8001                                   
-#define NV_SYSTEM_ACPI_BATTERY_POWER_EVENT   0x8002                                   
-#define NV_SYSTEM_ACPI_DOCK_EVENT            0x8003                                   
+#define NVIF_DISPLAY_DEVICE_CHANGE_EVENT     NVIF_NOTIFY_DISPLAY_DETECT
+/*
+ * NVIDIA ACPI event IDs to be passed into the core NVIDIA
+ * driver for various events like display switch events,
+ * AC/battery events, docking events, etc..
+ */
+#define NV_SYSTEM_ACPI_DISPLAY_SWITCH_EVENT  0x8001
+#define NV_SYSTEM_ACPI_BATTERY_POWER_EVENT   0x8002
+#define NV_SYSTEM_ACPI_DOCK_EVENT            0x8003
 
 /*
  * Status bit definitions for display switch hotkey events.
@@ -448,15 +456,15 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 #define NV_HOTKEY_STATUS_DISPLAY_ENABLE_TV  0x04
 #define NV_HOTKEY_STATUS_DISPLAY_ENABLE_DFP 0x08
 
-/*                                                                                    
- * NVIDIA ACPI sub-event IDs (event types) to be passed into                          
- * to core NVIDIA driver for ACPI events.                                             
- */                                                                                   
-#define NV_SYSTEM_ACPI_EVENT_VALUE_DISPLAY_SWITCH_DEFAULT    0                        
-#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_AC            0                        
-#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_BATTERY       1                        
-#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_UNDOCKED       0                        
-#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_DOCKED         1                        
+/*
+ * NVIDIA ACPI sub-event IDs (event types) to be passed into
+ * to core NVIDIA driver for ACPI events.
+ */
+#define NV_SYSTEM_ACPI_EVENT_VALUE_DISPLAY_SWITCH_DEFAULT    0
+#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_AC            0
+#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_BATTERY       1
+#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_UNDOCKED       0
+#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_DOCKED         1
 
 #define NV_ACPI_NVIF_HANDLE_PRESENT 0x01
 #define NV_ACPI_DSM_HANDLE_PRESENT  0x02
@@ -588,8 +596,7 @@ void*      NV_API_CALL  nv_alloc_kernel_mapping  (nv_state_t *, void *, NvU64, N
 NV_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, void *);
 NV_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, void *, NvU64, NvU32, NvU64, NvU32, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, NvU64, void *);
-NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, NvU32, void *, NvU64, void *, void **);
-void       NV_API_CALL  nv_destroy_user_mapping_context (nv_state_t *, void *, void *);
+NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, void **);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
@@ -604,6 +611,9 @@ NV_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvBool, N
 NV_STATUS  NV_API_CALL  nv_register_user_pages   (nv_state_t *, NvU64, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_unregister_user_pages (nv_state_t *, NvU64, void **);
 
+NV_STATUS NV_API_CALL   nv_register_user_physical_addresses (nv_state_t *, NvU64, NvU64 *, void **);
+NV_STATUS NV_API_CALL   nv_unregister_user_physical_addresses (nv_state_t *, NvU64, void *);
+
 NV_STATUS  NV_API_CALL  nv_dma_map_pages         (nv_state_t *, NvU64, NvU64 *, NvBool, void **);
 NV_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *, void **);
 
@@ -643,6 +653,9 @@ NvBool     NV_API_CALL  nv_requires_dma_remap    (nv_state_t *);
 NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
 #endif
 
+nv_fd_memdesc_t* NV_API_CALL nv_get_fd_memdesc   (void *);
+NV_STATUS  NV_API_CALL  nv_add_fd_memdesc_to_fd  (NvU32, const nv_fd_memdesc_t*);
+
 /*
  * ---------------------------------------------------------------------------
  *
@@ -782,8 +795,8 @@ void       NV_API_CALL rm_gpu_ops_p2p_object_destroy(nvidia_stack_t *, nvgpuSess
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_big_page_size(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvU32 *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_external_alloc_ptes(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvHandle, NvU64, NvU64, nvgpuExternalMappingInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, nvgpuChannelInstanceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, NvU32, nvgpuChannelResourceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, NvU32, nvgpuChannelResourceBindParams_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, nvgpuChannelResourceInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, nvgpuChannelResourceBindParams_t);
 void       NV_API_CALL rm_gpu_ops_release_channel(nvidia_stack_t *, NvP64);
 void       NV_API_CALL rm_gpu_ops_release_channel_resources(nvidia_stack_t *, NvP64*, NvU32);
 void       NV_API_CALL rm_gpu_ops_stop_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvBool);
@@ -791,7 +804,8 @@ NV_STATUS  NV_API_CALL rm_gpu_ops_get_channel_resource_ptes(nvidia_stack_t *, nv
 void       NV_API_CALL rm_kernel_rmapi_op(nvidia_stack_t *sp, void *ops_cmd);
 NV_STATUS  NV_API_CALL rm_gpu_copy_mmu_faults(nvidia_stack_t *, nv_state_t *, NvU32 *);
 NV_STATUS  NV_API_CALL rm_gpu_copy_mmu_faults_unlocked(nvidia_stack_t *, nv_state_t *, NvU32 *);
-
+NV_STATUS  NV_API_CALL rm_gpu_need_4k_page_isolation(nv_state_t *, NvBool *);
+NvBool     NV_API_CALL rm_is_chipset_io_coherent(nv_stack_t *); 
 #endif /* NVWATCH */
 
 #endif /* NVRM */
