@@ -889,18 +889,3 @@ NV_STATUS NV_API_CALL os_get_smbios_header(NvU64 *pSmbsAddr)
     return NV_ERR_NOT_SUPPORTED;
 }
 
-NV_STATUS NV_API_CALL os_get_acpi_rsdp_from_uefi
-(
-    NvU32  *pRsdpAddr
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-void NV_API_CALL os_add_record_for_crashLog(void *pbuffer, NvU32 size)
-{
-}
-
-void NV_API_CALL os_delete_record_for_crashLog(void *pbuffer)
-{
-}
