@@ -795,6 +795,21 @@ void nv_unlock_api(nv_state_t *nv)
     sx_xunlock(&sc->api_sx);
 }
 
+nv_fd_memdesc_t* NV_API_CALL nv_get_fd_memdesc(
+    void       *file
+)
+{
+    return NULL;
+}
+
+NV_STATUS NV_API_CALL nv_add_fd_memdesc_to_fd(
+    NvU32                  fd,
+    const nv_fd_memdesc_t *pFdMemdesc
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
 void NV_API_CALL nv_post_event(
     nv_state_t *nv,
     nv_event_t *event,
@@ -930,10 +945,6 @@ NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     nv_state_t *nv,
     NvU64 address,
     NvU64 size,
-    NvU32 prot,
-    void *pAllocPriv,
-    NvU64 pageIndex,
-    void *file,
     void **ppPrivate
 )
 {
@@ -941,14 +952,6 @@ NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     return NV_OK;
 }
 
-void NV_API_CALL nv_destroy_user_mapping_context(
-    nv_state_t *nv,
-    void *pFile,
-    void *pPrivate
-)
-{
-}
-
 NV_STATUS NV_API_CALL nv_alloc_user_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
